Template Tags — Django Stories 1.0 documentation

Django Stories 1.0 documentation

# Template Tags

- Table of Contents
- index
  modules
  next
  previous

# Template Tags

class `stories.relations.templatetags.story_relation_tags.` `RelatedNode`(obj, var_name, content_type=None, relation_type=None)

  Main related object node that handles multiple template tags:

  - get_related_content
  - get_related_content_type
  - get_relation_type
  `render`(context)

`stories.relations.templatetags.story_relation_tags.` `do_get_related_content`(parser, token)

  Gets all relations to a story

  Syntax:

      {% get_related_content item as var_name %}

  Example:

      {% get_related_content story as story_rels %}

`stories.relations.templatetags.story_relation_tags.` `do_get_related_content_type`(parser, token)

  Gets relations to a story based on the content type

  Syntax:

      {% get_related_content_type item content_type as var_name %}

  Example:

      {% get_related_content_type story Image as story_photos %}

`stories.relations.templatetags.story_relation_tags.` `do_get_relation_type`(parser, token)

  Gets the relations to a story based on the relation type

  Syntax:

      {% get_relation_type item relation_type as var_name %}

  Example:

      {% get_relation_type story leadphoto as leadphoto %}

`stories.templatetags.quickedit.` `results`(cl)

`stories.templatetags.quickedit.` `qe_result_list`(context, cl)